@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '4.4001_002'; # TRIAL
+$BZ::Client::Bug::VERSION = '4.4001_003'; # TRIAL
 
-$BZ::Client::Bug::VERSION = '4.4001002';
+$BZ::Client::Bug::VERSION = '4.4001003';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -288,7 +288,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 4.4001_002
+version 4.4001_003
 
 =head1 SYNOPSIS
 
@@ -961,6 +961,18 @@ I<resolution> (string) - If you are filing a closed bug, then you will have to s
 
 I<target_milestone> (string) - A valid target milestone for this product.
 
+=item depends_on
+
+I<depends_on> (array) - An array of bug id's that this new bug should depend upon.
+
+As of Bugzilla 5.0 this option isn't included in the WebService API docks for =create()=, although it is mentioned in it's error codes.
+
+=item blocks
+
+I<blocks> (array) - An array of bug id's that this new bug should block.
+
+As of Bugzilla 5.0 this option isn't included in the WebService API docks for =create()=, although it is mentioned in it's error codes.
+
 =back
 
 B<Note:> In addition to the above parameters, if your installation has any custom fields, you can set them just by passing in the name of the field and its value as a string.
